@@ -116,6 +116,10 @@ class Basic(DefinitionBase, CoreServiceInterface):
                     if hasattr(val_obj, 'close'):
                         val_obj.close()
 
+    def clear_cache_method(self, method=None):
+        for k, v in self.cachedict.items():
+            self.clear_cache(k, method)
+
     @staticmethod
     def set_paths(data_path, certbase, serv_certbase, rights,
                   group_rights, sids, pids, sids_pids, sids_file, pids_file,
